@@ -12,7 +12,7 @@ use Carp;
 #==================================================================
 
 use vars qw($VERSION);
-$VERSION = '1.00';
+$VERSION = '1.01';
 
 use base qw/Tk::Derived Tk::Canvas/;
 use Tk::Balloon;
@@ -91,6 +91,7 @@ sub Populate {
     -boxaxis      => [ 'PASSIVE', 'Boxaxis',      'BoxAxis',      0 ],
     -noaxis       => [ 'PASSIVE', 'Noaxis',       'NoAxis',       0 ],
     -zeroaxisonly => [ 'PASSIVE', 'Zeroaxisonly', 'ZeroAxisOnly', 0 ],
+    -zeroaxis => [ 'PASSIVE', 'Zeroaxis', 'ZeroAxis', 0 ],
     -gridview     => [ 'PASSIVE', 'Gridview',     'GridView',     0 ],
 
     -xtickheight => [
@@ -1299,6 +1300,14 @@ sub _GraphForDummiesConstruction {
     $CompositeWidget->delete(
       $CompositeWidget->{RefInfoDummies}->{TAGS}{xAxis} );
   }
+  if (  $CompositeWidget->cget( -zeroaxis ) == 1 ) {
+    $CompositeWidget->delete(
+      $CompositeWidget->{RefInfoDummies}->{TAGS}{xAxis0} );
+    $CompositeWidget->delete(
+      $CompositeWidget->{RefInfoDummies}->{TAGS}{xTick} );
+    $CompositeWidget->delete(
+      $CompositeWidget->{RefInfoDummies}->{TAGS}{xValues} );
+  }
 
   # ticks
   my $alltickview = $CompositeWidget->cget( -alltickview );
@@ -1514,24 +1523,6 @@ sub set_balloon {
 
 }
 
-sub _DestroyBalloonAndBind {
-  my ($CompositeWidget) = @_;
-
-  # balloon defined and user want to stop it
-  if ( defined $CompositeWidget->{RefInfoDummies}->{Balloon}{Obj}
-    and $CompositeWidget->{RefInfoDummies}->{Balloon}{State} == 0 )
-  {
-    $CompositeWidget->{RefInfoDummies}->{Balloon}{Obj}
-      ->configure( -state => 'none' );
-    $CompositeWidget->{RefInfoDummies}->{Balloon}{Obj}
-      ->detach($CompositeWidget);
-    $CompositeWidget->{RefInfoDummies}->{Balloon}{Obj}->destroy;
-
-    undef $CompositeWidget->{RefInfoDummies}->{Balloon}{Obj};
-  }
-
-  return;
-}
 
 1;
 __END__
@@ -1970,6 +1961,21 @@ Hide the axis with ticks and values ticks.
 
 Default : B<0>
 
+=item Name:	B<Zeroaxis>
+
+=item Class:	B<ZeroAxis>
+
+=item Switch:	B<-zeroaxis>
+
+If set to a true value, the axis for y values of 0 will always be drawn. 
+This might be useful in case your graph contains negative values, 
+but you want it to be clear where the zero value is. 
+(see also zeroaxisonly and boxaxis).
+
+ -zeroaxis => 1, # 0 or 1
+
+Default : B<0>
+
 =item Name:	B<Zeroaxisonly>
 
 =item Class:	B<ZeroAxisOnly>
@@ -2627,7 +2633,7 @@ See L<Tk::ForDummies::Graph>, L<GD::Graph>, L<Tk::Graph>, L<Tk::LineGraph>, L<Tk
 
 You can find documentation for this module with the perldoc command.
 
-    perldoc Tk::ForDummies::Graph::Lines
+    perldoc Tk::ForDummies::Graph::Bars
 
 
 You can also look for information at:
